@@ -44,17 +44,35 @@ def main():
     else:
         document = {}
 
-    app = cde.MainWindow(APP_NAME, pagestack=True)
-    modified = app.run(cde.EditorPage(os.path.basename(args.document), schema, document))
-    if modified:
-        if doc_ext in ['.yaml', '.yml', '.json']:
-            with open(args.document, 'wt') as f:
-                if doc_ext in ['.yaml', '.yml']:
-                    f.write(yaml_parser.dump(modified))
-                elif doc_ext in ['.json']:
-                    f.write(json.dumps(modified, indent=2))
-        else:
-            print(f'Cannot support file format.', file=sys.stderr)
+    if False:
+        from cerberus_document_editor.validator import Validator
+        from cerberus_kind import utils
+        
+        validator = Validator(schema, purge_unknown=True)
+        import time
+
+        b = time.time()
+        print('validate:', validator.validate(document, normalize=False))
+        print(utils.parse_error(validator.errors, with_path=True))
+        print(json.dumps(validator.normalized(document), indent=2))
+        #print(json.dumps(dict(validator.schema), indent=2))
+        #validator.normalized_by_order()
+        #print(json.dumps(validator.normalized_by_order(document), indent=2))
+        #print(json.dumps(validator.normalized(document, ordered=True), indent=2))
+        #print(json.dumps(validator.document, indent=2))
+        print(f"{time.time()-b}s")
+    else:
+        app = cde.MainWindow(APP_NAME, pagestack=True)
+        modified = app.run(cde.EditorPage(os.path.basename(args.document), schema, document))
+        if modified:
+            if doc_ext in ['.yaml', '.yml', '.json']:
+                with open(args.document, 'wt') as f:
+                    if doc_ext in ['.yaml', '.yml']:
+                        f.write(yaml_parser.dump(modified))
+                    elif doc_ext in ['.json']:
+                        f.write(json.dumps(modified, indent=2))
+            else:
+                print(f'Cannot support file format.', file=sys.stderr)
 
 if __name__ == '__main__':
     main()
\ No newline at end of file
